==> kubernetes-model-certificates-5.1.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestStatusFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestStatusFluent<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent<A>> extends Fluent<A> {


    public String getCertificate();
    public A withCertificate(String certificate);
    public Boolean hasCertificate();
    public A withNewCertificate(String arg1);
    public A withNewCertificate(StringBuilder arg1);
    public A withNewCertificate(StringBuffer arg1);
    public A addToConditions(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public A setToConditions(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public A addToConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
    public A addAllToConditions(Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
    public A removeFromConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
    public A removeAllFromConditions(Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
    public A removeMatchingFromConditions(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> getConditions();
    public List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> buildConditions();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildCondition(int index);
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildFirstCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildLastCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public A withConditions(List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> conditions);
    public A withConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... conditions);
    public Boolean hasConditions();
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(int index);
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
    public CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionFluent<CertificateSigningRequestStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}

==> kubernetes-model-certificates-5.3.2-sources.jar: annotations/io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestStatusFluent.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface CertificateSigningRequestStatusFluent<A extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public String getCertificate();
    public A withCertificate(String certificate);
    public Boolean hasCertificate();
    public A withNewCertificate(StringBuilder arg1);
    public A withNewCertificate(int[] arg1,int arg2,int arg3);
    public A withNewCertificate(char[] arg1);
    public A withNewCertificate(StringBuffer arg1);
    public A withNewCertificate(byte[] arg1,int arg2);
    public A withNewCertificate(byte[] arg1);
    public A withNewCertificate(char[] arg1,int arg2,int arg3);
    public A withNewCertificate(byte[] arg1,int arg2,int arg3);
    public A withNewCertificate(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewCertificate(String arg1);
    public A addToConditions(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public A setToConditions(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public A addToConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
    public A addAllToConditions(Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
    public A removeFromConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... items);
    public A removeAllFromConditions(Collection<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> items);
    public A removeMatchingFromConditions(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildConditions instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> getConditions();
    public List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> buildConditions();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildCondition(int index);
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildFirstCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildLastCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition buildMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public Boolean hasMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public A withConditions(List<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition> conditions);
    public A withConditions(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition... conditions);
    public Boolean hasConditions();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> addNewConditionLike(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> setNewConditionLike(int index,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestCondition item);
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editCondition(int index);
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editFirstCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editLastCondition();
    public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<A> editMatchingCondition(Predicate<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionBuilder> predicate);
    public interface ConditionsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestConditionFluent<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestStatusFluent.ConditionsNested<N>> {

            public N and();
            public N endCondition();    }


}
